@@ -114,7 +114,7 @@ CmdFctType cmd_key_cmds[] =
 
 	{"L03K05", {"flat review",	 	NULL}},	
 	{"L03K04", {"window hierarchy",	 	NULL}},
-	{"L03K07", {"window hierarchy flat",	NULL}},
+	{"L03K07", {"read whole window",	NULL}},
 	{"L03K06", {"detailed informations", 	NULL}},	
 	{"L03K02", {"do default action", 	NULL}},	
 	{"L03K03", {"window overview", 		NULL}},	
