@@ -1738,10 +1738,10 @@ src_process_config_changed_for_control (SRConfigStructure *config)
 static void
 src_process_change_for_presentation (gboolean first)
 {
-    gchar *name = "default";
+    gchar *name = DEFAULT_PRESENTATION_ACTIVE_SETTING_NAME;
     gchar *name2;
-	
-    srconf_get_data_with_default (PRESENTATION_ACTIVE_SETTING, CFGT_STRING, &name, &name, PRESENTATION_PATH);
+
+    srconf_get_data_with_default (PRESENTATION_ACTIVE_SETTING, CFGT_STRING, &name, name, PRESENTATION_PATH);
 
     name2 = g_strconcat (PRESENTATION_DIR, name, ".xml", NULL); 
     if (!first)
