@@ -697,7 +697,8 @@ srl_is_window_event (SRLEvent *event)
 {
     srl_assert (event);
     
-    if (srle_acc_has_role (event, SPI_ROLE_TOOL_TIP))
+    if (srle_acc_has_role (event, SPI_ROLE_TOOL_TIP) ||
+	srle_acc_has_role (event, SPI_ROLE_WINDOW))
 	return FALSE;
     return  event->type == SRL_EVENT_WINDOW_CREATE   ||
 	    event->type == SRL_EVENT_WINDOW_DESTROY  ||
@@ -1130,6 +1131,30 @@ srle_is_for_watched_acc (SRLEvent *event)
     return srl_watched_acc == event->acc_ev->source;
 }
 
+static gboolean
+srle_is_for_focused_ancestor_acc (SRLEvent *event)
+{
+    Accessible *acc;
+    gboolean rv = FALSE;
+    srl_assert (event);
+
+    acc = event->acc_ev->source;
+    Accessible_ref (acc);
+    while (acc)
+    {
+	Accessible *tmp;
+	rv = srl_acc_has_state (acc, SPI_STATE_FOCUSED);
+	if (rv)
+	    break;
+	tmp = acc;
+	acc = Accessible_getParent (tmp);
+	Accessible_unref (tmp);
+    }
+    if (acc)
+	Accessible_unref (acc);
+    return rv;
+}
+
 
 static gboolean
 srle_is_for_focused_acc (SRLEvent *event)
@@ -1167,7 +1192,6 @@ srl_event_is_for_metacity (SRLEvent *event)
     return rv;
 }
 
-
 static gboolean
 srle_change_type (SRLEvent *event)
 {
@@ -1197,7 +1221,8 @@ srle_change_type (SRLEvent *event)
 	    event->type = SRL_EVENT_FOCUS;
 */
 	if (!srle_is_for_focused_acc (event) &&
-	    !srle_is_for_watched_acc (event))
+	    !srle_is_for_watched_acc (event) &&
+	    srle_is_for_focused_ancestor_acc (event))
 	    event->type = SRL_EVENT_FOCUS2;
 	if (last_link_index != new_link_index)
 	    event->type = SRL_EVENT_FOCUS;
